summaryrefslogtreecommitdiffstats
path: root/usr/local/www/diag_tables.php
diff options
context:
space:
mode:
authorScott Ullrich <sullrich@pfsense.org>2010-08-25 18:08:59 -0400
committerScott Ullrich <sullrich@pfsense.org>2010-08-25 18:08:59 -0400
commitc07b05e01c6c54ba882f3f5c3f2fc8b3d03354cf (patch)
tree402569d0328f04f1bc513c51bc3748b7f1dd5179 /usr/local/www/diag_tables.php
parent450bf4e2f644fbfd7a902b9cc898ece32ffaace6 (diff)
downloadpfsense-c07b05e01c6c54ba882f3f5c3f2fc8b3d03354cf.zip
pfsense-c07b05e01c6c54ba882f3f5c3f2fc8b3d03354cf.tar.gz
s/overload//
Diffstat (limited to 'usr/local/www/diag_tables.php')
-rw-r--r--usr/local/www/diag_tables.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/usr/local/www/diag_tables.php b/usr/local/www/diag_tables.php
index 9c409c6..9551e51 100644
--- a/usr/local/www/diag_tables.php
+++ b/usr/local/www/diag_tables.php
@@ -1,6 +1,6 @@
<?php
/*
- diag_overload_tables.php
+ diag_tables.php
Copyright (C) 2010 Jim Pingle
Portions borrowed from diag_dump_states.php:
@@ -35,13 +35,13 @@
*/
##|+PRIV
##|*IDENT=page-diagnostics-overload-tables
##|*NAME=Diagnostics: PF Overload table IP addresses
##|*DESCR=Allow access to the 'Diagnostics: Overload tables' page.
##|*MATCH=diag_overload_tables.php*
##|-PRIV
-$pgtitle = array(gettext("Diagnostics"), gettext("Overload tables"));
+$pgtitle = array(gettext("Diagnostics"), gettext("Tables"));
require_once("guiconfig.inc");
@@ -82,10 +82,10 @@ include("fbegin.inc");
<script language="javascript">
function method_change(entrytype) {
- window.location='diag_overload_tables.php?type=' + entrytype;
+ window.location='diag_tables.php?type=' + entrytype;
}
function del_entry(entry) {
- new Ajax.Request("diag_overload_tables.php?type=<?php echo $tablename;?>&delete=" + entry, {
+ new Ajax.Request("diag_tables.php?type=<?php echo $tablename;?>&delete=" + entry, {
onComplete: function(response) {
if (200 == response.status)
new Effect.Fade($(response.responseText), { duration: 1.0 } );
@@ -133,7 +133,7 @@ include("fbegin.inc");
<?php
if($count > 0)
- echo "<p/>" . gettext("Delete") . " <a href='diag_overload_tables.php?deleteall=true&type={$tablename}'>" . gettext("all") . "</a> " . gettext("entries in this table.");
+ echo "<p/>" . gettext("Delete") . " <a href='diag_tables.php?deleteall=true&type={$tablename}'>" . gettext("all") . "</a> " . gettext("entries in this table.");
?>
OpenPOWER on IntegriCloud
@@ -35,13 +35,13 @@
*/
##|+PRIV
-##|*IDENT=page-diagnostics-overload-tables
-##|*NAME=Diagnostics: PF Overload table IP addresses
-##|*DESCR=Allow access to the 'Diagnostics: Overload tables' page.
-##|*MATCH=diag_overload_tables.php*
+##|*IDENT=page-diagnostics-tables
+##|*NAME=Diagnostics: PF Table IP addresses
+##|*DESCR=Allow access to the 'Diagnostics: Tables' page.
+##|*MATCH=diag_tables.php*
##|-PRIV